@@ -16,8 +16,9 @@ class RabbitMQ:
         self.password = flask.current_app.config['VIGGOCORE_QUEUE_PASSWORD']
         credentials = PlainCredentials(self.username, self.password)
         self.params = ConnectionParameters(
-            self.url, self.port, self.virtual_host, credentials, heartbeat=10,
-            blocked_connection_timeout=7)
+            self.url, self.port, self.virtual_host, credentials, heartbeat=60,
+            blocked_connection_timeout=30, socket_timeout=None, retry_delay=10,
+            connection_attempts=10000)
 
     def connect(self):
         try:
